@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,7 +16,7 @@ from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_iot_data.type_defs import (
+from .type_defs import (
     DeleteThingShadowResponseTypeDef,
     GetThingShadowResponseTypeDef,
     ListNamedShadowsForThingResponseTypeDef,
@@ -50,8 +50,8 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -59,16 +59,16 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def delete_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> DeleteThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#delete-thing-shadow)
         """
 
     def generate_presigned_url(
@@ -79,36 +79,36 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> GetThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#get-thing-shadow)
         """
 
     def list_named_shadows_for_thing(
         self, thingName: str, nextToken: str = None, pageSize: int = None
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list-named-shadows-for-thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3-stubs documentation](./client.md#list-named-shadows-for-thing)
         """
 
     def publish(self, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.publish)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3-stubs documentation](./client.md#publish)
         """
 
     def update_thing_shadow(
         self, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
     ) -> UpdateThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#update-thing-shadow)
         """
